@@ -51,7 +51,7 @@ use clitype::*;
 use std::fmt::Debug;
 use std::mem::size_of;
 
-mod util;
+pub mod util;
 pub use util::*;
 
 /// A [`CLIType`] must be specified when creating a [`CLI`] object.
@@ -368,7 +368,7 @@ pub enum Error {
 
 impl std::fmt::Display for Error {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
-        write!(f, "{}", self)
+        write!(f, "{:?}", self)
     }
 }
 
@@ -627,4 +627,9 @@ $$GEOMETRYSTART          // start of GEOMETRY-section//
         assert_eq!(header.version, 1.05);
         Ok(())
     }
+    #[test]
+    fn errors() {
+        assert_eq!("NoHeader", &format!("{}", Error::NoHeader));
+        assert_eq!("NoHeader", &format!("{:?}", Error::NoHeader));
+    }
 }
